@@ -560,9 +560,9 @@ impl AsRawFd for Dir {
 }
 
 #[cfg(not(windows))]
-impl<'f> AsFd<'f> for &'f Dir {
+impl AsFd for Dir {
     #[inline]
-    fn as_fd(self) -> BorrowedFd<'f> {
+    fn as_fd(&self) -> BorrowedFd<'_> {
         self.cap_std.as_fd()
     }
 }
@@ -576,9 +576,9 @@ impl AsRawHandle for Dir {
 }
 
 #[cfg(windows)]
-impl<'h> AsHandle<'h> for &'h Dir {
+impl AsHandle for Dir {
     #[inline]
-    fn as_handle(self) -> BorrowedHandle<'h> {
+    fn as_handle(&self) -> BorrowedHandle<'_> {
         self.cap_std.as_handle()
     }
 }
